@@ -7,7 +7,6 @@ from django.forms.models import inlineformset_factory
 from django import forms
 from django.conf import settings
 from django.contrib import messages
-from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 
 from polls.models import Choice, Poll, UserChoice, AnonymousUserChoice
 from polls.forms import PollForm, PollVoteForm
@@ -26,29 +25,6 @@ class PollListView(ListView):
         
         return queryset
     
-    def get_context_data(self, *args, **kwargs):
-        context = super(PollListView, self).get_context_data(*args, **kwargs)
-        
-        page_count = getattr(
-                settings,
-                'POLL_PAGE_COUNT',
-                5)
-                
-        paginator = Paginator(self.get_queryset(), page_count)
-        
-        page = self.request.GET.get('page')        
-        
-        try:
-            polls = paginator.page(page)
-        except PageNotAnInteger:
-            polls = paginator.page(1)
-        except EmptyPage:
-            polls = paginator.page(paginator.num_pages)
-        
-        context['object_list'] = polls
-        
-        return context
-        
 class ResultsView(DetailView):
     model = Poll
     template_name = 'polls/results.html'
